summaryrefslogtreecommitdiff
path: root/indra/newview/llappviewer.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llappviewer.h')
-rw-r--r--indra/newview/llappviewer.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/indra/newview/llappviewer.h b/indra/newview/llappviewer.h
index 902b94d495..5332fe2deb 100644
--- a/indra/newview/llappviewer.h
+++ b/indra/newview/llappviewer.h
@@ -1,6 +1,5 @@
/**
* @mainpage
- * @mainpage
*
* This is the sources for the Second Life Viewer;
* information on the open source project is at
@@ -83,7 +82,7 @@ public:
virtual bool frame(); // Override for application body logic
// Application control
- void flushLFSIO(); // waits for lfs transfers to complete
+ void flushVFSIO(); // waits for vfs transfers to complete
void forceQuit(); // Puts the viewer into 'shutting down without error' mode.
void fastQuit(S32 error_code = 0); // Shuts down the viewer immediately after sending a logout message
void requestQuit(); // Request a quit. A kinder, gentler quit.
@@ -382,6 +381,12 @@ extern BOOL gRestoreGL;
extern bool gUseWireframe;
extern bool gInitialDeferredModeForWireframe;
+// VFS globals - gVFS is for general use
+// gStaticVFS is read-only and is shipped w/ the viewer
+// it has pre-cache data like the UI .TGAs
+class LLVFS;
+extern LLVFS *gStaticVFS;
+
extern LLMemoryInfo gSysMemory;
extern U64Bytes gMemoryAllocated;